#
# spec file for package gemrb
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gemrb
Version:        0.9.3
Release:        1.1
Summary:        Game engine made with pre-rendered background
License:        GPL-2.0-or-later
Group:          Amusements/Games/RPG
URL:            http://www.gemrb.org/
Source:         https://github.com/%{name}/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         link-ptread-core-explicitly.patch
BuildRequires:  cmake >= 3.19
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(freetype2)
# reenable once OpenGL rendering stops being experimental (same for the cmake flags below)
# BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libvlc)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(zlib)

%description
GemRB is an implementation of Bioware's Infinity Engine which was
written to support pseudo-3D role playing games based on the
Dungeons & Dragons ruleset.

You will need the original game files of Baldur's Gate and the Icewind
Dale series or Planescape: Torment to play.

%prep
%autosetup -p1
sed -ie 's,\(#!/usr/bin/python\)$,\13,' admin/extend2da.py

%build
rm -Rf CMakeCache.txt CMakeFiles/
%cmake -DCMAKE_INSTALL_PREFIX:PATH=%{_prefix} \
    -DLIB_DIR=%{_libdir} \
    -DPLUGIN_DIR=%{_libdir}/gemrb/plugins \
    -DDISABLE_WERROR=1 \
    -DCMAKE_VERBOSE_MAKEFILE:BOOL="true" \
#    -DOPENGL_BACKEND=OpenGL

%make_jobs

%install
%cmake_install
%fdupes -s %{buildroot}/%{_datadir}/gemrb
rm %{buildroot}%{_datadir}/doc/gemrb/INSTALL
rm %{buildroot}%{_libdir}/libgemrb*.so

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%{_bindir}/extend2da.py
%{_bindir}/gemrb
%dir %{_libdir}/gemrb/plugins
%dir %{_libdir}/gemrb
%{_libdir}/gemrb/plugins/
%{_libdir}/lib*
%{_mandir}/man6/gemrb.6%{?ext_man}
%{_datadir}/gemrb/
%{_datadir}/doc/gemrb/
%{_datadir}/metainfo/org.gemrb.gemrb.metainfo.xml
%{_datadir}/pixmaps/gemrb.png
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/gemrb.svg
%{_datadir}/applications/gemrb.desktop
%config %{_sysconfdir}/gemrb/

%changelog
* Sun Jul 14 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to 0.9.3
  * New features:
    + full i18n (language) support, custom journal entries
    + chunking approximation
    + BMP v3 and v5 support
    + small test suite, tracy support
    + iwd2 identification variants and speed data
    + nwn-for-bg2 compatibility
  * Improved features:
    + area music, creature & area sounds
    + colored logging, pathfinding, drawing
    + ee compat, effects, modals, projectiles, familiars
    + iwd2 & pst worldmap
    + switched to c++14, build system
    + bugfixes
- update BuildRequires
* Wed Oct 18 2023 Dirk Stöcker <github@dstoecker.de>
- update to 0.9.2
  * optional CapFPS, GameLanguagePath and GameMoviesPath keys have
    been added to the sample configs
* Fri Dec  9 2022 Steve Kowalik <steven.kowalik@suse.com>
- Change shebang of a shipped script to use Python 3.
* Wed Dec  7 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.9.1.1:
  * New features:
    + faster loading and saving, faster OpenGL rendering
    + basic resolution independence
    + python3 support
    + arbitrary window dragging support
    + improved debug console
    + subtitle support for BIK videos
    + gameplay content for the demo
    + Heart of Fury support
    + SDLAudio caching and volume control
    + PlayStation Vita port
    + simpler invocation, AppImage packages
  * Improved features:
    + unicode support (iconv not optional any more!)
    + window management, drawing and input handling
    + performance: SDL2 video playback, general and text rendering
    + smoother movement animations, demo
    + lightning bolts, iwd2 stealth, iwd effects, pst levelup
    + scripting, audio backends, logging
    + build system, portability and performance improvements
    + externalized summoning limit, trap limit, narration text speed
- Switch BuildRequires to Python 3
- Add patch link-ptread-core-explicitly.patch:
  * Link gemrb_core against the threading library explicitly.
* Mon Aug 24 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.8.7
  * new smarter pathfinder with bumping support
  * animal taming, iwd2 hardcoded saving throw bonuses
  * vcpkg and out-of-the box msvc support
  * non-ascii data filename support
  * switched to c++11 and cmake 3.1 as a minimum
* Sat Jan 18 2020 Jaka Kranjc <registracije+factory@lynxlynx.info>
- update to 0.8.6
- use the main renderer while the OpenGL one remains experimental
  * new features:
  - more audio, especially in bg1 and pst
  - sndchann.2da support
  - using bags in stores, NPC breaking points, worldmap travel in pst
  * improved features:
  - better megamod and detectable spells compatibility
  - iwd2 and pst levelup, infopoints, gui feedback, dualclassing, ranges
  - verbal constants, (tobex) opcodes, falling, paperdolls, projectiles
  - pst area animations, multipalette animations
  - bugfixes
* Fri Aug 31 2018 Ondřej Súkup <mimi.vx@gmail.com>
- use OpenGL GLVND driver
- install libgemrb_core directly to %%{_libdir}
* Fri Dec  8 2017 mimi.vx@gmail.com
- update to 0.8.5
- use SDL2 and enable openGL support
  * new features:
  - SDL2 resolution-independent window scaling, environmental audio
  - regeneration during sleep, time dilation
  - iwd2 ability stacking, iwd ZZ* weapon bonuses
  - portrait.2da handling, avatar shadows, dialogF.tlk handling
  * impoved features:
  - infravision
  - better compatibility with bgt, 10pp, ia, kelsey, dr
  - sdl2 input, mouse scrolling, opengl driver
  - iwd2 cg&lu, item (un)usability, avatar sizes, permanent clabs
  - ambients, verbal constants, random walk, walk sounds
  - bugfixes
* Thu Sep 29 2016 jengelh@inai.de
- Trim redundant words from description.
  Remove unnecessary ldconfig call (no direct shared libs)
* Mon Jun 20 2016 mimi.vx@gmail.com
- update to 0.8.4
  * New features:
  - pst should be roughly completable
  - iwd2 level-up, concealment, hardcoded clabs, tracking
  - ToBEx simplified "concentration" option, spontaneous casting for everyone
  - bg1, iwd2, (pst) casting sounds
  * Improved features:
  - iwd2 spells (shapes, songs, crossclass mixing, learning), action bar
  - lots of pst details and annoyances
  - stores, dialogs, scripts, iwd and pst effects
  - bugfixes
* Wed Dec 30 2015 mailaender@opensuse.org
- update to version 0.8.3.1
* Sun Aug 25 2013 mailaender@opensuse.org
- initial packaging
